==> ejc-jlincome-api-3.0.0-20240723.064147-201-sources.jar: com/ejianc/business/jlincome/income/vo/DisclosureConDetailsVO.java <==
package com.ejianc.business.jlincome.income.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 收入管理-合同交底-合同明细子表
 * 
 * @author generator
 * 
 */
public class DisclosureConDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long disclosureId; // 主表id
    private String detailProductName; // 产品名称
    private String detailSpec; // 规格型号
    private String detailUnit; // 单位
    private BigDecimal detailNum; // 数量
    private BigDecimal detailTaxPrice; // 单价
    private BigDecimal detailRate; // 税率
    private BigDecimal detailTaxMny; // 金额
    private BigDecimal detailPrice; // 单价（无税）
    private BigDecimal detailMny; // 金额（无税）
    private BigDecimal detailTax; // 税额
    private Date detailPlanDeliverDate; // 预计交货日期
    private String detailMemo; // 备注

    public Date getDetailPlanDeliverDate() {
        return detailPlanDeliverDate;
    }

    public void setDetailPlanDeliverDate(Date detailPlanDeliverDate) {
        this.detailPlanDeliverDate = detailPlanDeliverDate;
    }

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }
    public String getDetailProductName() {
        return detailProductName;
    }

    public void setDetailProductName(String detailProductName) {
        this.detailProductName = detailProductName;
    }
    public String getDetailSpec() {
        return detailSpec;
    }

    public void setDetailSpec(String detailSpec) {
        this.detailSpec = detailSpec;
    }
    public String getDetailUnit() {
        return detailUnit;
    }

    public void setDetailUnit(String detailUnit) {
        this.detailUnit = detailUnit;
    }
    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }
    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }
    public BigDecimal getDetailRate() {
        return detailRate;
    }

    public void setDetailRate(BigDecimal detailRate) {
        this.detailRate = detailRate;
    }
    public BigDecimal getDetailTaxMny() {
        return detailTaxMny;
    }

    public void setDetailTaxMny(BigDecimal detailTaxMny) {
        this.detailTaxMny = detailTaxMny;
    }
    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public BigDecimal getDetailTax() {
        return detailTax;
    }

    public void setDetailTax(BigDecimal detailTax) {
        this.detailTax = detailTax;
    }

    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}

==> ejc-jlincome-api-3.0.0-20241115.080528-371-sources.jar: com/ejianc/business/jlincome/income/vo/DisclosureConDetailsVO.java <==
package com.ejianc.business.jlincome.income.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 收入管理-合同交底-合同明细子表
 * 
 * @author generator
 * 
 */
public class DisclosureConDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long disclosureId; // 主表id
    private String detailProductName; // 产品名称
    private String detailSpec; // 规格型号
    private String detailUnit; // 单位
    private BigDecimal detailNum; // 数量
    private BigDecimal detailTaxPrice; // 单价
    private BigDecimal detailRate; // 税率
    private BigDecimal detailTaxMny; // 金额
    private BigDecimal detailPrice; // 单价（无税）
    private BigDecimal detailMny; // 金额（无税）
    private BigDecimal detailTax; // 税额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date detailPlanDeliverDate; // 预计交货日期
    private String detailMemo; // 备注
    private String billCode; //计划单号
    private Long sourceId;//计划子表Id
    private Long sourceBillId;//计划主表id

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getSourceBillId() {
        return sourceBillId;
    }

    public void setSourceBillId(Long sourceBillId) {
        this.sourceBillId = sourceBillId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Date getDetailPlanDeliverDate() {
        return detailPlanDeliverDate;
    }

    public void setDetailPlanDeliverDate(Date detailPlanDeliverDate) {
        this.detailPlanDeliverDate = detailPlanDeliverDate;
    }

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }
    public String getDetailProductName() {
        return detailProductName;
    }

    public void setDetailProductName(String detailProductName) {
        this.detailProductName = detailProductName;
    }
    public String getDetailSpec() {
        return detailSpec;
    }

    public void setDetailSpec(String detailSpec) {
        this.detailSpec = detailSpec;
    }
    public String getDetailUnit() {
        return detailUnit;
    }

    public void setDetailUnit(String detailUnit) {
        this.detailUnit = detailUnit;
    }
    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }
    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }
    public BigDecimal getDetailRate() {
        return detailRate;
    }

    public void setDetailRate(BigDecimal detailRate) {
        this.detailRate = detailRate;
    }
    public BigDecimal getDetailTaxMny() {
        return detailTaxMny;
    }

    public void setDetailTaxMny(BigDecimal detailTaxMny) {
        this.detailTaxMny = detailTaxMny;
    }
    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public BigDecimal getDetailTax() {
        return detailTax;
    }

    public void setDetailTax(BigDecimal detailTax) {
        this.detailTax = detailTax;
    }

    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}
